@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: x509
 version: 1.6.3
-id: x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
-key: x509_Jt1nFxQKP0d8cHOIU7gzoq
+id: x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
+key: x509_7d7izp22mhiF4F7b1SppwP
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -26,17 +26,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
 library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
 data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-1.6.3
-hs-libraries: HSx509-1.6.3-Jt1nFxQKP0d8cHOIU7gzoq
+hs-libraries: HSx509-1.6.3-7d7izp22mhiF4F7b1SppwP
 depends:
-    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
-    asn1-parse-0.9.4-7a8ff0bd98d1e72c778de11c366d8b51
-    asn1-types-0.3.2-3969820adc8283f126affe054010f830
+    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
+    asn1-parse-0.9.4-b064d91c5d9874d8c61bb184f001f6aa
+    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
+    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
     hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
-    memory-0.11-3a745e41fe78387f608c420e9b455d25
+    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
 haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
